summaryrefslogtreecommitdiff
path: root/include/util_filter.h
diff options
context:
space:
mode:
authorJim Jagielski <jim@apache.org>2011-11-24 15:53:16 +0000
committerJim Jagielski <jim@apache.org>2011-11-24 15:53:16 +0000
commitf66d79b8b2567a9ab29ff31fc842834fc15d2b3f (patch)
treedfc7e7aed82d241c0a4ca9c018ddc3bff6a05f72 /include/util_filter.h
parentfae7207c35403df6ab9b1f829b0daa69d74489ff (diff)
downloadhttpd-f66d79b8b2567a9ab29ff31fc842834fc15d2b3f.tar.gz
Use varargs...
git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@1205894 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/util_filter.h')
-rw-r--r--include/util_filter.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/util_filter.h b/include/util_filter.h
index 4b4236529f..cc2a0f76e3 100644
--- a/include/util_filter.h
+++ b/include/util_filter.h
@@ -322,8 +322,8 @@ AP_DECLARE(apr_status_t) ap_pass_brigade(ap_filter_t *filter,
* ::HTTP_INTERNAL_SERVER_ERROR on all other errors
* @param r The request rec
* @param bucket The current bucket brigade
* @param msg Optional error msg; if NULL defaults to "ap_pass_brigade returned"
*
* @remark Ownership of the brigade is retained by the caller. On return,
* the contents of the brigade are UNDEFINED, and the caller must
* either call apr_brigade_cleanup or apr_brigade_destroy on
@@ -331,7 +331,8 @@ AP_DECLARE(apr_status_t) ap_pass_brigade(ap_filter_t *filter,
*/
AP_DECLARE(apr_status_t) ap_pass_brigade_fchk(request_rec *r,
apr_bucket_brigade *bucket,
- const char *msg);
+ const char *fmt,
+ ...);
/**
@@ -574,7 +575,7 @@ AP_DECLARE_NONSTD(apr_status_t) ap_fputstrs(ap_filter_t *f,
* @param f the filter we are writing to
* @param bb The brigade to buffer into
* @param fmt The format string
- * @param ... The argumets to use to fill out the format string
+ * @param ... The arguments to use to fill out the format string
*/
AP_DECLARE_NONSTD(apr_status_t) ap_fprintf(ap_filter_t *f,
apr_bucket_brigade *bb,
@@ -322,8 +322,8 @@ AP_DECLARE(apr_status_t) ap_pass_brigade(ap_filter_t *filter,
* @param r The request rec
* @param bucket The current bucket brigade
- * @param msg Optional error msg; if NULL defaults to "ap_pass_brigade returned"
- *
+ * @param fmt The format string. If NULL defaults to "ap_pass_brigade returned"
+ * @param ... The arguments to use to fill out the format string
* @remark Ownership of the brigade is retained by the caller. On return,
* the contents of the brigade are UNDEFINED, and the caller must